@@ -1,4 +1,5 @@
 """The types module contains custom types used by pydantic."""
+
 from __future__ import annotations as _annotations
 
 import base64
@@ -35,14 +36,7 @@ from annotated_types import BaseMetadata, MaxLen, MinLen
 from pydantic_core import CoreSchema, PydanticCustomError, core_schema
 from typing_extensions import Annotated, Literal, Protocol, TypeAlias, TypeAliasType, deprecated
 
-from ._internal import (
-    _core_utils,
-    _fields,
-    _internal_dataclass,
-    _typing_extra,
-    _utils,
-    _validators,
-)
+from ._internal import _core_utils, _fields, _internal_dataclass, _typing_extra, _utils, _validators
 from ._migration import getattr_migration
 from .annotated_handlers import GetCoreSchemaHandler, GetJsonSchemaHandler
 from .errors import PydanticUserError
@@ -109,6 +103,7 @@ __all__ = (
     'Discriminator',
     'JsonValue',
     'OnErrorOmit',
+    'FailFast',
 )
 
 
@@ -117,9 +112,10 @@ T = TypeVar('T')
 
 @_dataclasses.dataclass
 class Strict(_fields.PydanticMetadata, BaseMetadata):
-    """Usage docs: https://docs.pydantic.dev/2.7/concepts/strict_mode/#strict-mode-with-annotated-strict
+    """Usage docs: https://docs.pydantic.dev/2.9/concepts/strict_mode/#strict-mode-with-annotated-strict
 
     A field metadata class to indicate that a field should be validated in strict mode.
+    Use this class as an annotation via [`Annotated`](https://docs.python.org/3/library/typing.html#typing.Annotated), as seen below.
 
     Attributes:
         strict: Whether to validate the field in strict mode.
@@ -227,7 +223,7 @@ def conint(
     ```
 
     """  # noqa: D212
-    return Annotated[
+    return Annotated[  # pyright: ignore[reportReturnType]
         int,
         Strict(strict) if strict is not None else None,
         annotated_types.Interval(gt=gt, ge=ge, lt=lt, le=le),
@@ -385,7 +381,21 @@ except ValidationError as e:
 
 @_dataclasses.dataclass
 class AllowInfNan(_fields.PydanticMetadata):
-    """A field metadata class to indicate that a field should allow ``-inf``, ``inf``, and ``nan``."""
+    """A field metadata class to indicate that a field should allow `-inf`, `inf`, and `nan`.
+
+    Use this class as an annotation via [`Annotated`](https://docs.python.org/3/library/typing.html#typing.Annotated), as seen below.
+
+    Attributes:
+        allow_inf_nan: Whether to allow `-inf`, `inf`, and `nan`. Defaults to `True`.
+
+    Example:
+        ```python
+        from typing_extensions import Annotated
+
+        from pydantic.types import AllowInfNan
+
+        LaxFloat = Annotated[float, AllowInfNan()]
+    """
 
     allow_inf_nan: bool = True
 
@@ -473,7 +483,7 @@ def confloat(
         '''
     ```
     """  # noqa: D212
-    return Annotated[
+    return Annotated[  # pyright: ignore[reportReturnType]
         float,
         Strict(strict) if strict is not None else None,
         annotated_types.Interval(gt=gt, ge=ge, lt=lt, le=le),
@@ -661,7 +671,7 @@ def conbytes(
     Returns:
         The wrapped bytes type.
     """
-    return Annotated[
+    return Annotated[  # pyright: ignore[reportReturnType]
         bytes,
         Strict(strict) if strict is not None else None,
         annotated_types.Len(min_length or 0, max_length),
@@ -677,18 +687,27 @@ StrictBytes = Annotated[bytes, Strict()]
 
 @_dataclasses.dataclass(frozen=True)
 class StringConstraints(annotated_types.GroupedMetadata):
-    """Usage docs: https://docs.pydantic.dev/2.7/concepts/fields/#string-constraints
+    """Usage docs: https://docs.pydantic.dev/2.9/concepts/fields/#string-constraints
 
-    Apply constraints to `str` types.
+    A field metadata class to apply constraints to `str` types.
+    Use this class as an annotation via [`Annotated`](https://docs.python.org/3/library/typing.html#typing.Annotated), as seen below.
 
     Attributes:
-        strip_whitespace: Whether to strip whitespace from the string.
+        strip_whitespace: Whether to remove leading and trailing whitespace.
         to_upper: Whether to convert the string to uppercase.
         to_lower: Whether to convert the string to lowercase.
         strict: Whether to validate the string in strict mode.
         min_length: The minimum length of the string.
         max_length: The maximum length of the string.
         pattern: A regex pattern that the string must match.
+
+    Example:
+        ```python
+        from typing_extensions import Annotated
+
+        from pydantic.types import StringConstraints
+
+        ConstrainedStr = Annotated[str, StringConstraints(min_length=1, max_length=10)]
     """
 
     strip_whitespace: bool | None = None
@@ -705,7 +724,7 @@ class StringConstraints(annotated_types.GroupedMetadata):
         if self.max_length is not None:
             yield MaxLen(self.max_length)
         if self.strict is not None:
-            yield Strict()
+            yield Strict(self.strict)
         if (
             self.strip_whitespace is not None
             or self.pattern is not None
@@ -716,7 +735,7 @@ class StringConstraints(annotated_types.GroupedMetadata):
                 strip_whitespace=self.strip_whitespace,
                 to_upper=self.to_upper,
                 to_lower=self.to_lower,
-                pattern=self.pattern.pattern if isinstance(self.pattern, Pattern) else self.pattern,
+                pattern=self.pattern,
             )
 
 
@@ -755,7 +774,12 @@ def constr(
             from pydantic import BaseModel, StringConstraints
 
             class Foo(BaseModel):
-                bar: Annotated[str, StringConstraints(strip_whitespace=True, to_upper=True, pattern=r'^[A-Z]+$')]
+                bar: Annotated[
+                    str,
+                    StringConstraints(
+                        strip_whitespace=True, to_upper=True, pattern=r'^[A-Z]+$'
+                    ),
+                ]
             ```
 
     A wrapper around `str` that allows for additional constraints.
@@ -764,8 +788,7 @@ def constr(
     from pydantic import BaseModel, constr
 
     class Foo(BaseModel):
-        bar: constr(strip_whitespace=True, to_upper=True, pattern=r'^[A-Z]+$')
-
+        bar: constr(strip_whitespace=True, to_upper=True)
 
     foo = Foo(bar='  hello  ')
     print(foo)
@@ -784,7 +807,7 @@ def constr(
     Returns:
         The wrapped string type.
     """  # noqa: D212
-    return Annotated[
+    return Annotated[  # pyright: ignore[reportReturnType]
         str,
         StringConstraints(
             strip_whitespace=strip_whitespace,
@@ -819,7 +842,7 @@ def conset(
     Returns:
         The wrapped set type.
     """
-    return Annotated[Set[item_type], annotated_types.Len(min_length or 0, max_length)]
+    return Annotated[Set[item_type], annotated_types.Len(min_length or 0, max_length)]  # pyright: ignore[reportReturnType]
 
 
 def confrozenset(
@@ -835,7 +858,7 @@ def confrozenset(
     Returns:
         The wrapped frozenset type.
     """
-    return Annotated[FrozenSet[item_type], annotated_types.Len(min_length or 0, max_length)]
+    return Annotated[FrozenSet[item_type], annotated_types.Len(min_length or 0, max_length)]  # pyright: ignore[reportReturnType]
 
 
 AnyItemType = TypeVar('AnyItemType')
@@ -870,7 +893,7 @@ def conlist(
             ),
             code='removed-kwargs',
         )
-    return Annotated[List[item_type], annotated_types.Len(min_length or 0, max_length)]
+    return Annotated[List[item_type], annotated_types.Len(min_length or 0, max_length)]  # pyright: ignore[reportReturnType]
 
 
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~ IMPORT STRING TYPE ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -893,15 +916,13 @@ else:
 
         **Good behavior:**
         ```py
-        from math import cos
+        import math
 
         from pydantic import BaseModel, Field, ImportString, ValidationError
 
-
         class ImportThings(BaseModel):
             obj: ImportString
 
-
         # A string value will cause an automatic import
         my_cos = ImportThings(obj='math.cos')
 
@@ -909,7 +930,6 @@ else:
         cos_of_0 = my_cos.obj(0)
         assert cos_of_0 == 1
 
-
         # A string whose value cannot be imported will raise an error
         try:
             ImportThings(obj='foo.bar')
@@ -918,32 +938,27 @@ else:
             '''
             1 validation error for ImportThings
             obj
-            Invalid python path: No module named 'foo.bar' [type=import_error, input_value='foo.bar', input_type=str]
+              Invalid python path: No module named 'foo.bar' [type=import_error, input_value='foo.bar', input_type=str]
             '''
 
-
         # Actual python objects can be assigned as well
-        my_cos = ImportThings(obj=cos)
+        my_cos = ImportThings(obj=math.cos)
         my_cos_2 = ImportThings(obj='math.cos')
         my_cos_3 = ImportThings(obj='math:cos')
         assert my_cos == my_cos_2 == my_cos_3
 
-
         # You can set default field value either as Python object:
         class ImportThingsDefaultPyObj(BaseModel):
             obj: ImportString = math.cos
 
-
         # or as a string value (but only if used with `validate_default=True`)
         class ImportThingsDefaultString(BaseModel):
             obj: ImportString = Field(default='math.cos', validate_default=True)
 
-
         my_cos_default1 = ImportThingsDefaultPyObj()
         my_cos_default2 = ImportThingsDefaultString()
         assert my_cos_default1.obj == my_cos_default2.obj == math.cos
 
-
         # note: this will not work!
         class ImportThingsMissingValidateDefault(BaseModel):
             obj: ImportString = 'math.cos'
@@ -954,14 +969,12 @@ else:
 
         Serializing an `ImportString` type to json is also possible.
 
-        ```py
+        ```py lint="skip"
         from pydantic import BaseModel, ImportString
 
-
         class ImportThings(BaseModel):
             obj: ImportString
 
-
         # Create an instance
         m = ImportThings(obj='math.cos')
         print(m)
@@ -990,12 +1003,25 @@ else:
                     function=_validators.import_string, schema=handler(source), serialization=serializer
                 )
 
+        @classmethod
+        def __get_pydantic_json_schema__(cls, cs: CoreSchema, handler: GetJsonSchemaHandler) -> JsonSchemaValue:
+            return handler(core_schema.str_schema())
+
         @staticmethod
         def _serialize(v: Any) -> str:
             if isinstance(v, ModuleType):
                 return v.__name__
             elif hasattr(v, '__module__') and hasattr(v, '__name__'):
                 return f'{v.__module__}.{v.__name__}'
+            # Handle special cases for sys.XXX streams
+            # if we see more of these, we should consider a more general solution
+            elif hasattr(v, 'name'):
+                if v.name == '<stdout>':
+                    return 'sys.stdout'
+                elif v.name == '<stdin>':
+                    return 'sys.stdin'
+                elif v.name == '<stderr>':
+                    return 'sys.stderr'
             else:
                 return v
 
@@ -1091,7 +1117,7 @@ def condecimal(
         '''
     ```
     """  # noqa: D212
-    return Annotated[
+    return Annotated[  # pyright: ignore[reportReturnType]
         Decimal,
         Strict(strict) if strict is not None else None,
         annotated_types.Interval(gt=gt, ge=ge, lt=lt, le=le),
@@ -1106,7 +1132,23 @@ def condecimal(
 
 @_dataclasses.dataclass(**_internal_dataclass.slots_true)
 class UuidVersion:
-    """A field metadata class to indicate a [UUID](https://docs.python.org/3/library/uuid.html) version."""
+    """A field metadata class to indicate a [UUID](https://docs.python.org/3/library/uuid.html) version.
+
+    Use this class as an annotation via [`Annotated`](https://docs.python.org/3/library/typing.html#typing.Annotated), as seen below.
+
+    Attributes:
+        uuid_version: The version of the UUID. Must be one of 1, 3, 4, or 5.
+
+    Example:
+        ```python
+        from typing_extensions import Annotated
+        from uuid import UUID
+
+        from pydantic.types import UuidVersion
+
+        UUID1 = Annotated[UUID, UuidVersion(1)]
+        ```
+    """
 
     uuid_version: Literal[1, 3, 4, 5]
 
@@ -1330,7 +1372,7 @@ except ValidationError as e:
 ```
 """
 NewPath = Annotated[Path, PathType('new')]
-"""A path for a new file or directory that must not already exist."""
+"""A path for a new file or directory that must not already exist. The parent directory must already exist."""
 
 
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ JSON TYPE ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -1352,15 +1394,12 @@ else:
 
         from pydantic import BaseModel, Json, ValidationError
 
-
         class AnyJsonModel(BaseModel):
             json_obj: Json[Any]
 
-
         class ConstrainedJsonModel(BaseModel):
             json_obj: Json[List[int]]
 
-
         print(AnyJsonModel(json_obj='{"b": 1}'))
         #> json_obj={'b': 1}
         print(ConstrainedJsonModel(json_obj='[1, 2, 3]'))
@@ -1373,7 +1412,7 @@ else:
             '''
             1 validation error for ConstrainedJsonModel
             json_obj
-            JSON input should be string, bytes or bytearray [type=json_type, input_value=12, input_type=int]
+              JSON input should be string, bytes or bytearray [type=json_type, input_value=12, input_type=int]
             '''
 
         try:
@@ -1383,7 +1422,7 @@ else:
             '''
             1 validation error for ConstrainedJsonModel
             json_obj
-            Invalid JSON: expected value at line 1 column 2 [type=json_invalid, input_value='[a, b]', input_type=str]
+              Invalid JSON: expected value at line 1 column 2 [type=json_invalid, input_value='[a, b]', input_type=str]
             '''
 
         try:
@@ -1393,9 +1432,9 @@ else:
             '''
             2 validation errors for ConstrainedJsonModel
             json_obj.0
-            Input should be a valid integer, unable to parse string as an integer [type=int_parsing, input_value='a', input_type=str]
+              Input should be a valid integer, unable to parse string as an integer [type=int_parsing, input_value='a', input_type=str]
             json_obj.1
-            Input should be a valid integer, unable to parse string as an integer [type=int_parsing, input_value='b', input_type=str]
+              Input should be a valid integer, unable to parse string as an integer [type=int_parsing, input_value='b', input_type=str]
             '''
         ```
 
@@ -1407,11 +1446,9 @@ else:
 
         from pydantic import BaseModel, Json
 
-
         class ConstrainedJsonModel(BaseModel):
             json_obj: Json[List[int]]
 
-
         print(ConstrainedJsonModel(json_obj='[1, 2, 3]').model_dump_json())
         #> {"json_obj":[1,2,3]}
         print(
@@ -1439,7 +1476,7 @@ else:
             return hash(type(self))
 
         def __eq__(self, other: Any) -> bool:
-            return type(other) == type(self)
+            return type(other) is type(self)
 
 
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ SECRET TYPES ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -1561,14 +1598,22 @@ class Secret(_SecretBase[SecretType]):
             validated_inner = handler(value)
             return cls(validated_inner)
 
+        def serialize(value: Secret[SecretType], info: core_schema.SerializationInfo) -> str | Secret[SecretType]:
+            if info.mode == 'json':
+                return str(value)
+            else:
+                return value
+
         return core_schema.json_or_python_schema(
             python_schema=core_schema.no_info_wrap_validator_function(
                 validate_secret_value,
                 inner_schema,
-                serialization=core_schema.plain_serializer_function_ser_schema(lambda x: x),
             ),
-            json_schema=core_schema.no_info_after_validator_function(
-                lambda x: cls(x), inner_schema, serialization=core_schema.to_string_ser_schema(when_used='json')
+            json_schema=core_schema.no_info_after_validator_function(lambda x: cls(x), inner_schema),
+            serialization=core_schema.plain_serializer_function_ser_schema(
+                serialize,
+                info_arg=True,
+                when_used='always',
             ),
         )
 
@@ -1990,7 +2035,7 @@ class ByteSize(int):
 
 def _check_annotated_type(annotated_type: str, expected_type: str, annotation: str) -> None:
     if annotated_type != expected_type:
-        raise PydanticUserError(f"'{annotation}' cannot annotate '{annotated_type}'.", code='invalid_annotated_type')
+        raise PydanticUserError(f"'{annotation}' cannot annotate '{annotated_type}'.", code='invalid-annotated-type')
 
 
 if TYPE_CHECKING:
@@ -2057,7 +2102,7 @@ def condate(
     Returns:
         A date type with the specified constraints.
     """
-    return Annotated[
+    return Annotated[  # pyright: ignore[reportReturnType]
         date,
         Strict(strict) if strict is not None else None,
         annotated_types.Interval(gt=gt, ge=ge, lt=lt, le=le),
@@ -2582,7 +2627,7 @@ __getattr__ = getattr_migration(__name__)
 
 @_dataclasses.dataclass(**_internal_dataclass.slots_true)
 class GetPydanticSchema:
-    """Usage docs: https://docs.pydantic.dev/2.7/concepts/types/#using-getpydanticschema-to-reduce-boilerplate
+    """Usage docs: https://docs.pydantic.dev/2.9/concepts/types/#using-getpydanticschema-to-reduce-boilerplate
 
     A convenience class for creating an annotation that provides pydantic custom type hooks.
 
@@ -2718,7 +2763,7 @@ class Tag:
 
 @_dataclasses.dataclass(**_internal_dataclass.slots_true, frozen=True)
 class Discriminator:
-    """Usage docs: https://docs.pydantic.dev/2.7/concepts/unions/#discriminated-unions-with-callable-discriminator
+    """Usage docs: https://docs.pydantic.dev/2.9/concepts/unions/#discriminated-unions-with-callable-discriminator
 
     Provides a way to use a custom callable as the way to extract the value of a union discriminator.
 
@@ -2827,7 +2872,7 @@ class Discriminator:
             original_schema = core_schema.union_schema([original_schema])
 
         tagged_union_choices = {}
-        for i, choice in enumerate(original_schema['choices']):
+        for choice in original_schema['choices']:
             tag = None
             if isinstance(choice, tuple):
                 choice, tag = choice
@@ -2994,3 +3039,36 @@ this annotation omits the item from the iteration if there is any error validati
 That is, instead of a [`ValidationError`][pydantic_core.ValidationError] being propagated up and the entire iterable being discarded
 any invalid items are discarded and the valid ones are returned.
 """
+
+
+@_dataclasses.dataclass
+class FailFast(_fields.PydanticMetadata, BaseMetadata):
+    """A `FailFast` annotation can be used to specify that validation should stop at the first error.
+
+    This can be useful when you want to validate a large amount of data and you only need to know if it's valid or not.
+
+    You might want to enable this setting if you want to validate your data faster (basically, if you use this,
+    validation will be more performant with the caveat that you get less information).
+
+    ```py
+    from typing import List
+    from typing_extensions import Annotated
+    from pydantic import BaseModel, FailFast, ValidationError
+
+    class Model(BaseModel):
+        x: Annotated[List[int], FailFast()]
+
+    # This will raise a single error for the first invalid value and stop validation
+    try:
+        obj = Model(x=[1, 2, 'a', 4, 5, 'b', 7, 8, 9, 'c'])
+    except ValidationError as e:
+        print(e)
+        '''
+        1 validation error for Model
+        x.2
+          Input should be a valid integer, unable to parse string as an integer [type=int_parsing, input_value='a', input_type=str]
+        '''
+    ```
+    """
+
+    fail_fast: bool = True
