@@ -1,9 +1,15 @@
 """Pydantic-specific warnings."""
+
 from __future__ import annotations as _annotations
 
 from .version import version_short
 
-__all__ = 'PydanticDeprecatedSince20', 'PydanticDeprecationWarning'
+__all__ = (
+    'PydanticDeprecatedSince20',
+    'PydanticDeprecationWarning',
+    'PydanticDeprecatedSince26',
+    'PydanticExperimentalWarning',
+)
 
 
 class PydanticDeprecationWarning(DeprecationWarning):
@@ -47,5 +53,27 @@ class PydanticDeprecatedSince20(PydanticDeprecationWarning):
         super().__init__(message, *args, since=(2, 0), expected_removal=(3, 0))
 
 
+class PydanticDeprecatedSince26(PydanticDeprecationWarning):
+    """A specific `PydanticDeprecationWarning` subclass defining functionality deprecated since Pydantic 2.6."""
+
+    def __init__(self, message: str, *args: object) -> None:
+        super().__init__(message, *args, since=(2, 6), expected_removal=(3, 0))
+
+
+class PydanticDeprecatedSince29(PydanticDeprecationWarning):
+    """A specific `PydanticDeprecationWarning` subclass defining functionality deprecated since Pydantic 2.9."""
+
+    def __init__(self, message: str, *args: object) -> None:
+        super().__init__(message, *args, since=(2, 9), expected_removal=(3, 0))
+
+
 class GenericBeforeBaseModelWarning(Warning):
     pass
+
+
+class PydanticExperimentalWarning(Warning):
+    """A Pydantic specific experimental functionality warning.
+
+    This warning is raised when using experimental functionality in Pydantic.
+    It is raised to warn users that the functionality may change or be removed in future versions of Pydantic.
+    """
